ReqRep - Blueye SDK

Skip to content

# ReqRep

## `` req_rep

Classes:

- `ConnectClientRep` –

  Response after connecting a client to the drone.

- `ConnectClientReq` –

  Connect a new client to the drone.

- `DisconnectClientRep` –

  Response after disconnecting a client from the drone.

- `DisconnectClientReq` –

  Disconnect a client from the drone.

- `FlashEscSettingsRep` –

  Response after flashing ESC settings.

- `FlashEscSettingsReq` –

  Request to flash ESC settings.

- `GetBatteryRep` –

  Response with essential battery information.

- `GetBatteryReq` –

  Request essential battery information.

- `GetCameraParametersRep` –

  Response with the currently set camera parameters.

- `GetCameraParametersReq` –

  Request to get the currently set camera parameters.

- `GetMissionRep` –

  Get active mission response.

- `GetMissionReq` –

  Service request to the reference_generator to get the active

- `GetOverlayParametersRep` –

  Response with the currently set video overlay parameters.

- `GetOverlayParametersReq` –

  Request to get currently set video overlay parameters.

- `GetPersistentStorageSettingsRep` –

  Response with the currently set persistent storage settings.

- `GetPersistentStorageSettingsReq` –

  Request to get currently set persistent storage settings.

- `GetTelemetryRep` –

  Response with latest telemetry

- `GetTelemetryReq` –

  Request to get latest telemetry data

- `PingRep` –

  Response message from a PingReq request.

- `PingReq` –

  The simplest message to use to test request/reply

- `SetCameraParametersRep` –

  Response after setting the camera parameters.

- `SetCameraParametersReq` –

  Request to set camera parameters.

- `SetHeadingModeRep` –

  Response after setting the heading mode.

- `SetHeadingModeReq` –

  Set the heading mode used in dead reckoning.

- `SetInstructionUpdateRep` –

  Response after updating an instruction in the current

- `SetInstructionUpdateReq` –

  Updates an instruction in current mission with a new

- `SetMissionRep` –

  Response after setting a new mission.

- `SetMissionReq` –

  Issue a desired mission to the reference_generator.

- `SetOverlayParametersRep` –

  Response after setting video overlay parameters.

- `SetOverlayParametersReq` –

  Request to set video overlay parameters.

- `SetPersistentStorageSettingsRep` –

  Response after setting persistent storage settings.

- `SetPersistentStorageSettingsReq` –

  Request to set persistent storage settings.

- `SetPubFrequencyRep` –

  Response after updating publish frequency

- `SetPubFrequencyReq` –

  Request to update the publish frequency

- `SetThicknessGaugeParametersRep` –

  Response after setting thickness gauge parameters.

- `SetThicknessGaugeParametersReq` –

  Request to set parameters for ultrasonic thickness gauge.

- `SyncTimeRep` –

  Response after setting the system time on the drone.

- `SyncTimeReq` –

  Request to set the system time on the drone.

### `` ConnectClientRep

Response after connecting a client to the drone.

Contains information about which client is in control, and a list of all connected clients.

#### `` client_id `class-attribute` `instance-attribute`

    client_id: int = Field(UINT32, number=1)

#### `` client_id_in_control `class-attribute` `instance-attribute`

    client_id_in_control: int = Field(UINT32, number=2)

#### `` connected_clients `class-attribute` `instance-attribute`

    connected_clients: MutableSequence[ConnectedClient] = (
        RepeatedField(
            MESSAGE, number=3, message=ConnectedClient
        )
    )

### `` ConnectClientReq

Connect a new client to the drone.

#### `` client_info `class-attribute` `instance-attribute`

    client_info: ClientInfo = Field(
        MESSAGE, number=1, message=ClientInfo
    )

### `` DisconnectClientRep

Response after disconnecting a client from the drone.

Contains information about which clients are connected and in control.

#### `` client_id_in_control `class-attribute` `instance-attribute`

    client_id_in_control: int = Field(UINT32, number=1)

#### `` connected_clients `class-attribute` `instance-attribute`

    connected_clients: MutableSequence[ConnectedClient] = (
        RepeatedField(
            MESSAGE, number=2, message=ConnectedClient
        )
    )

### `` DisconnectClientReq

Disconnect a client from the drone.

This request will remove the client from the list of connected clients. It allows clients to disconnect instantly, without waiting for a watchdog to clear the client in control, or promote a new client to be in control.

#### `` client_id `class-attribute` `instance-attribute`

    client_id: int = Field(UINT32, number=1)

### `` FlashEscSettingsRep

Response after flashing ESC settings.

#### `` success `class-attribute` `instance-attribute`

    success: bool = Field(BOOL, number=1)

### `` FlashEscSettingsReq

Request to flash ESC settings.

#### `` silent `class-attribute` `instance-attribute`

    silent: bool = Field(BOOL, number=1)

### `` GetBatteryRep

Response with essential battery information.

#### `` battery `class-attribute` `instance-attribute`

    battery: Battery = Field(MESSAGE, number=1, message=Battery)

### `` GetBatteryReq

Request essential battery information.

Can be used to instantly get battery information, instead of having to wait for the BatteryTel message to be received.

### `` GetCameraParametersRep

Response with the currently set camera parameters.

#### `` camera_parameters `class-attribute` `instance-attribute`

    camera_parameters: CameraParameters = Field(
        MESSAGE, number=1, message=CameraParameters
    )

### `` GetCameraParametersReq

Request to get the currently set camera parameters.

#### `` camera `class-attribute` `instance-attribute`

    camera: Camera = Field(ENUM, number=1, enum=Camera)

### `` GetMissionRep

Get active mission response.

#### `` mission `class-attribute` `instance-attribute`

    mission: Mission = Field(MESSAGE, number=1, message=Mission)

### `` GetMissionReq

Service request to the reference_generator to get the active mission.

### `` GetOverlayParametersRep

Response with the currently set video overlay parameters.

#### `` overlay_parameters `class-attribute` `instance-attribute`

    overlay_parameters: OverlayParameters = Field(
        MESSAGE, number=1, message=OverlayParameters
    )

### `` GetOverlayParametersReq

Request to get currently set video overlay parameters.

### `` GetPersistentStorageSettingsRep

Response with the currently set persistent storage settings.

#### `` persistent_storage_settings `class-attribute` `instance-attribute`

    persistent_storage_settings: PersistentStorageSettings = (
        Field(
            MESSAGE, number=1, message=PersistentStorageSettings
        )
    )

### `` GetPersistentStorageSettingsReq

Request to get currently set persistent storage settings.

### `` GetTelemetryRep

Response with latest telemetry

#### `` payload `class-attribute` `instance-attribute`

    payload: Any = Field(MESSAGE, number=1, message=Any)

### `` GetTelemetryReq

Request to get latest telemetry data

#### `` message_type `class-attribute` `instance-attribute`

    message_type: str = Field(STRING, number=1)

### `` PingRep

Response message from a PingReq request.

### `` PingReq

The simplest message to use to test request/reply communication with the drone. The drone replies with a PingRep message immediately after receiving the PingReq.

### `` SetCameraParametersRep

Response after setting the camera parameters.

### `` SetCameraParametersReq

Request to set camera parameters.

#### `` camera_parameters `class-attribute` `instance-attribute`

    camera_parameters: CameraParameters = Field(
        MESSAGE, number=1, message=CameraParameters
    )

### `` SetHeadingModeRep

Response after setting the heading mode.

### `` SetHeadingModeReq

Set the heading mode used in dead reckoning.

#### `` heading_mode `class-attribute` `instance-attribute`

    heading_mode: HeadingMode = Field(
        ENUM, number=1, enum=HeadingMode
    )

### `` SetInstructionUpdateRep

Response after updating an instruction in the current mission.

### `` SetInstructionUpdateReq

Updates an instruction in current mission with a new instruction payload.

#### `` instruction `class-attribute` `instance-attribute`

    instruction: Instruction = Field(
        MESSAGE, number=1, message=Instruction
    )

### `` SetMissionRep

Response after setting a new mission.

### `` SetMissionReq

Issue a desired mission to the reference_generator.

#### `` mission `class-attribute` `instance-attribute`

    mission: Mission = Field(MESSAGE, number=1, message=Mission)

### `` SetOverlayParametersRep

Response after setting video overlay parameters.

### `` SetOverlayParametersReq

Request to set video overlay parameters.

#### `` overlay_parameters `class-attribute` `instance-attribute`

    overlay_parameters: OverlayParameters = Field(
        MESSAGE, number=1, message=OverlayParameters
    )

### `` SetPersistentStorageSettingsRep

Response after setting persistent storage settings.

#### `` success `class-attribute` `instance-attribute`

    success: bool = Field(BOOL, number=1)

### `` SetPersistentStorageSettingsReq

Request to set persistent storage settings.

#### `` persistent_storage_settings `class-attribute` `instance-attribute`

    persistent_storage_settings: PersistentStorageSettings = (
        Field(
            MESSAGE, number=1, message=PersistentStorageSettings
        )
    )

### `` SetPubFrequencyRep

Response after updating publish frequency

#### `` success `class-attribute` `instance-attribute`

    success: bool = Field(BOOL, number=1)

### `` SetPubFrequencyReq

Request to update the publish frequency

#### `` frequency `class-attribute` `instance-attribute`

    frequency: float = Field(FLOAT, number=2)

#### `` message_type `class-attribute` `instance-attribute`

    message_type: str = Field(STRING, number=1)

### `` SetThicknessGaugeParametersRep

Response after setting thickness gauge parameters.

### `` SetThicknessGaugeParametersReq

Request to set parameters for ultrasonic thickness gauge.

The sound velocity is used to calculate the thickness of the material being measured.

#### `` sound_velocity `class-attribute` `instance-attribute`

    sound_velocity: int = Field(UINT32, number=1)

### `` SyncTimeRep

Response after setting the system time on the drone.

#### `` success `class-attribute` `instance-attribute`

    success: bool = Field(BOOL, number=1)

### `` SyncTimeReq

Request to set the system time on the drone.

#### `` time `class-attribute` `instance-attribute`

    time: SystemTime = Field(
        MESSAGE, number=1, message=SystemTime
    )